.. _gammapy:

Gammapy Interoperability
========================

This module provides functions to convert the ``pyirf`` quantities
for IRFs and the binning to the corresponding ``gammapy`` classes.

Reference/API
-------------

.. automodapi:: pyirf.gammapy
   :no-inheritance-diagram:
